nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Inten

Struct Inten 

#[repr(transparent)]
pub struct Inten(pub u32);
PUF Interrupt Enable

Tuple Fields

0: u32

Implementations

Source

impl Inten

pub const fn readyen(&self) -> bool

Enable corresponding interrupt in STAT, which indicates that the initialization or a operation is completed.

pub const fn set_readyen(&mut self, val: bool)

Enable corresponding interrupt in STAT, which indicates that the initialization or a operation is completed.

pub const fn succesen(&self) -> bool

Enable corresponding interrupt in STAT, which indicates last operation was successful.

pub const fn set_succesen(&mut self, val: bool)

Enable corresponding interrupt in STAT, which indicates last operation was successful.

pub const fn erroren(&self) -> bool

Enable corresponding interrupt in STAT, which indicates that PUF is in the error state and no operations can be performed.

pub const fn set_erroren(&mut self, val: bool)

Enable corresponding interrupt in STAT, which indicates that PUF is in the error state and no operations can be performed.

pub const fn keyinreqen(&self) -> bool

Enable corresponding interrupt in STAT, which is request for next part of key.

pub const fn set_keyinreqen(&mut self, val: bool)

Enable corresponding interrupt in STAT, which is request for next part of key.

pub const fn keyoutavailen(&self) -> bool

Enable corresponding interrupt in STAT, which is next part of key is available.

pub const fn set_keyoutavailen(&mut self, val: bool)

Enable corresponding interrupt in STAT, which is next part of key is available.

pub const fn codeinreqen(&self) -> bool

Enable corresponding interrupt in STAT, which is request for next part of AC/KC.

pub const fn set_codeinreqen(&mut self, val: bool)

Enable corresponding interrupt in STAT, which is request for next part of AC/KC.

pub const fn codeoutavailen(&self) -> bool

Enable corresponding interrupt in STAT, which is next part of AC/KC is available.

pub const fn set_codeoutavailen(&mut self, val: bool)

Enable corresponding interrupt in STAT, which is next part of AC/KC is available.