#[repr(transparent)]pub struct Inten(pub u32);Expand description
PUF Interrupt Enable
Tuple Fields
0: u32Implementations
Sourceimpl Inten
impl Inten
Sourcepub const fn readyen(&self) -> bool
pub const fn readyen(&self) -> bool
Enable corresponding interrupt in STAT, which indicates that the initialization or a operation is completed.
Sourcepub const fn set_readyen(&mut self, val: bool)
pub const fn set_readyen(&mut self, val: bool)
Enable corresponding interrupt in STAT, which indicates that the initialization or a operation is completed.
Sourcepub const fn succesen(&self) -> bool
pub const fn succesen(&self) -> bool
Enable corresponding interrupt in STAT, which indicates last operation was successful.
Sourcepub const fn set_succesen(&mut self, val: bool)
pub const fn set_succesen(&mut self, val: bool)
Enable corresponding interrupt in STAT, which indicates last operation was successful.
Sourcepub const fn erroren(&self) -> bool
pub const fn erroren(&self) -> bool
Enable corresponding interrupt in STAT, which indicates that PUF is in the error state and no operations can be performed.
Sourcepub const fn set_erroren(&mut self, val: bool)
pub const fn set_erroren(&mut self, val: bool)
Enable corresponding interrupt in STAT, which indicates that PUF is in the error state and no operations can be performed.
Sourcepub const fn keyinreqen(&self) -> bool
pub const fn keyinreqen(&self) -> bool
Enable corresponding interrupt in STAT, which is request for next part of key.
Sourcepub const fn set_keyinreqen(&mut self, val: bool)
pub const fn set_keyinreqen(&mut self, val: bool)
Enable corresponding interrupt in STAT, which is request for next part of key.
Sourcepub const fn keyoutavailen(&self) -> bool
pub const fn keyoutavailen(&self) -> bool
Enable corresponding interrupt in STAT, which is next part of key is available.
Sourcepub const fn set_keyoutavailen(&mut self, val: bool)
pub const fn set_keyoutavailen(&mut self, val: bool)
Enable corresponding interrupt in STAT, which is next part of key is available.
Sourcepub const fn codeinreqen(&self) -> bool
pub const fn codeinreqen(&self) -> bool
Enable corresponding interrupt in STAT, which is request for next part of AC/KC.
Sourcepub const fn set_codeinreqen(&mut self, val: bool)
pub const fn set_codeinreqen(&mut self, val: bool)
Enable corresponding interrupt in STAT, which is request for next part of AC/KC.
Sourcepub const fn codeoutavailen(&self) -> bool
pub const fn codeoutavailen(&self) -> bool
Enable corresponding interrupt in STAT, which is next part of AC/KC is available.
Sourcepub const fn set_codeoutavailen(&mut self, val: bool)
pub const fn set_codeoutavailen(&mut self, val: bool)
Enable corresponding interrupt in STAT, which is next part of AC/KC is available.